.. redirect-from:: /users/prev_whats_new/github_stats_3.8.1

.. _github-stats-3-8-1:

GitHub statistics for 3.8.1 (Oct 31, 2023)
==========================================

GitHub statistics for 2023/09/15 (tag: v3.8.0) - 2023/10/31

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 24 issues and merged 95 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/85?closed=1>`__

The following 27 authors contributed 165 commits.

* 0taj
* Antony Lee
* Anvi Verma
* Artyom Romanov
* Augusto Borges
* Chiraag Balu
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* Eric Firing
* Gaurav-Kumar-Soni
* Greg Lucas
* Gurudatta Shanbhag
* hannah
* Hugues Hoppe
* Jody Klymak
* Joshua Stevenson
* Junpei Ota
* katotaisei
* Kyle Sunden
* Lucia Korpas
* Matthew Morrison
* Oscar Gustafsson
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann
* wemi3

GitHub issues and pull requests:

Pull Requests (95):

* :ghpull:`27239`: Backport PR #27237 on branch v3.8.x (DOC: Add command to install appropriate ``requirements.txt`` during dev venv setup)
* :ghpull:`27238`: Backport PR #27165 on branch v3.8.x (Fixing Matplotlib Notebook Text)
* :ghpull:`27165`: Fixing Matplotlib Notebook Text
* :ghpull:`27229`: Backport PR #27226 on branch v3.8.x (DOC: link out to troubleshooting guide in install)
* :ghpull:`27226`: DOC: link out to troubleshooting guide in install
* :ghpull:`27227`: Backport PR #27221 on branch v3.8.x (FIX: Enable interrupts on macosx event loops)
* :ghpull:`27221`: FIX: Enable interrupts on macosx event loops
* :ghpull:`27220`: Backport PR #27217 on branch v3.8.x: Fix type hints for undeprecated contour APIs
* :ghpull:`27217`: Fix type hints for undeprecated contour APIs
* :ghpull:`27212`: Backport PR #27088 on branch v3.8.x (Update ``find_nearest_contour`` and revert contour deprecations)
* :ghpull:`27207`: Backport PR #26970 on branch v3.8.x (FIX: Add PyOS_InputHook back to macos backend)
* :ghpull:`27088`: Update ``find_nearest_contour`` and revert contour deprecations
* :ghpull:`27206`: Backport PR #27205 on branch v3.8.x (Improve legend picking example)
* :ghpull:`26970`: FIX: Add PyOS_InputHook back to macos backend
* :ghpull:`27205`: Improve legend picking example
* :ghpull:`27202`: Backport PR #27178 on branch v3.8.x (Try/except import of Axes3D)
* :ghpull:`27178`: Try/except import of Axes3D
* :ghpull:`27201`: Backport PR #27179 on branch v3.8.x (Restore default behavior of hexbin mincnt with C provided)
* :ghpull:`27197`: Backport PR #27045 on branch v3.8.x (Ensure valid path mangling for ContourLabeler)
* :ghpull:`27179`: Restore default behavior of hexbin mincnt with C provided
* :ghpull:`27045`: Ensure valid path mangling for ContourLabeler
* :ghpull:`27191`: Backport PR #27189 on branch v3.8.x (Fix typo in docstring of ``matplotlib.colors.from_levels_and_colors``)
* :ghpull:`27189`: Fix typo in docstring of ``matplotlib.colors.from_levels_and_colors``
* :ghpull:`27154`: Backport PR #27153 on branch v3.8.x (Link xkcd color survey in named colors example)
* :ghpull:`27133`: Backport PR #27132 on branch v3.8.x (changed automated tests from subsection to section in workflow)
* :ghpull:`27131`: Backport PR #27118 on branch v3.8.x (Update developer release guide to follow conventions)
* :ghpull:`27118`: Update developer release guide to follow conventions
* :ghpull:`27122`: Backport PR #26930 on branch v3.8.x (Added documentation on getting full list of registered colormaps re: issue #26244)
* :ghpull:`26930`: Added documentation on getting full list of registered colormaps re: issue #26244
* :ghpull:`27113`: Backport PR #27039 on branch v3.8.x (Formatted docs)
* :ghpull:`27039`: Formatted release note docs
* :ghpull:`27101`: Backport PR #27096 on branch v3.8.x (make fonts.py, mathtext.py, text_intro.py confirm to docs guidelines)
* :ghpull:`27097`: Backport PR #27093 on branch v3.8.x ([Doc]: Move Automated Tests section to workflow docs #26998)
* :ghpull:`27065`: Backport PR #26943 on branch v3.8.x (ci: Run mypy against typed cycler)
* :ghpull:`26943`: ci: Run mypy against typed cycler
* :ghpull:`27060`: Backport PR #27059: ci: Clean up Python 3.12 builds
* :ghpull:`27057`: Backport PR #27040 on branch v3.8.x (Bump pypa/cibuildwheel from 2.16.1 to 2.16.2)
* :ghpull:`27059`: ci: Clean up Python 3.12 builds
* :ghpull:`27055`: Backport PR #27054 on branch v3.8.x (updated interactive.rst)
* :ghpull:`27052`: Backport PR #27036 on branch v3.8.x (updated artist_intro.rst)
* :ghpull:`27051`: Backport PR #26995 on branch v3.8.x (user/project/citing updated)
* :ghpull:`27046`: Backport PR #27043 on branch v3.8.x (updated api_interfaces.rst)
* :ghpull:`27040`: Bump pypa/cibuildwheel from 2.16.1 to 2.16.2
* :ghpull:`27041`: Backport PR #26908 on branch v3.8.x (``allsegs`` and ``allkinds`` return individual segments)
* :ghpull:`26908`: ``allsegs`` and ``allkinds`` return individual segments
* :ghpull:`27034`: Backport PR #27017 on branch v3.8.x (DOC: clarify usetex versus mathtext)
* :ghpull:`27017`: DOC: clarify usetex versus mathtext
* :ghpull:`27031`: Backport PR #27015 on branch v3.8.x (ValueError exception added to handle mix of {} and % string in colorbar format)
* :ghpull:`27015`: ValueError exception added to handle mix of {} and % string in colorbar format
* :ghpull:`27022`: BLD: Remove development dependencies from sdists
* :ghpull:`27023`: Backport PR #26883 on branch v3.8.x ([TYP] Type changes from running against Pandas)
* :ghpull:`26883`: [TYP] Type changes from running against Pandas
* :ghpull:`27018`: Backport PR #26961 on branch v3.8.x (DOC: made "open PR on MPL" a section in contribute guide)
* :ghpull:`27009`: Backport PR #27006 on branch v3.8.x (DOC: Fix resizing of animation examples)
* :ghpull:`26999`: Backport PR #26940 on branch v3.8.x (Add typing to pyplot.show() to avoid errors with mypy --strict.)
* :ghpull:`27000`: Backport PR #26605 on branch v3.8.x (ci: Install GTK4 from brew on macOS)
* :ghpull:`26982`: Backport PR #26976 on branch v3.8.x (Bump pypa/cibuildwheel from 2.16.0 to 2.16.1)
* :ghpull:`26940`: Add typing to pyplot.show() to avoid errors with mypy --strict.
* :ghpull:`26997`: Backport PR #26850 on branch v3.8.x (DOC: Fix missing-reference generation on Windows)
* :ghpull:`26860`: Backport PR #26849 on branch v3.8.x (Bump setuptools required version because of setuptools_scm v8)
* :ghpull:`26850`: DOC: Fix missing-reference generation on Windows
* :ghpull:`26987`: Backport PR #26985 on branch v3.8.x (Reformatted documentation under toolkits and tutorials directory )
* :ghpull:`26979`: Backport PR #26959 on branch v3.8.x (Move papersize="auto" deprecation to backend_bases.)
* :ghpull:`26976`: Bump pypa/cibuildwheel from 2.16.0 to 2.16.1
* :ghpull:`26959`: Move papersize="auto" deprecation to backend_bases.
* :ghpull:`26939`: Backport PR #26937 on branch v3.8.x (Add ArrayLike to scatter c arg type hint)
* :ghpull:`26964`: Backport PR #26952 on branch v3.8.x (FIX 2-tuple of colors in to_rgba_array)
* :ghpull:`26956`: Backport PR #26955 on branch v3.8.x (Fix incorrect skip check in test_backend_ps.)
* :ghpull:`26952`: FIX 2-tuple of colors in to_rgba_array
* :ghpull:`26955`: Fix incorrect skip check in test_backend_ps.
* :ghpull:`26945`: Backport PR #26927 on branch v3.8.x ([TYP] Remove some stubtest allowlist entries)
* :ghpull:`26927`: [TYP] Remove some stubtest allowlist entries
* :ghpull:`26937`: Add ArrayLike to scatter c arg type hint
* :ghpull:`26933`: Backport PR #26914 on branch v3.8.x (DOC: add a couple more placement examples, crosslink axes_grid [ci doc])
* :ghpull:`26849`: Bump setuptools required version because of setuptools_scm v8
* :ghpull:`26844`: Backport PR #26843 on branch v3.8.x (DOC: Use ax.xaxis rather ax.get_xaxis())
* :ghpull:`26836`: Backport PR #26834 on branch v3.8.x (Fix Issue 26821: [Bug]: ValueError: The truth value... when an ndarray is passed to the color kwarg of axes3d.scatter)
* :ghpull:`26834`: Fix Issue 26821: [Bug]: ValueError: The truth value... when an ndarray is passed to the color kwarg of axes3d.scatter
* :ghpull:`26835`: Backport PR #26814 on branch v3.8.x (Bump pypa/cibuildwheel from 2.15.0 to 2.16.0)
* :ghpull:`26828`: Backport PR #26825 on branch v3.8.x (Fix issue with non-string labels and legend)
* :ghpull:`26825`: Fix issue with non-string labels and legend
* :ghpull:`26814`: Bump pypa/cibuildwheel from 2.15.0 to 2.16.0
* :ghpull:`26816`: Backport PR #26799 on branch v3.8.x (Update kiwisolver and pillow versions to be consistent with requirements)
* :ghpull:`26820`: Backport PR #26811 on branch v3.8.x (Add overload for slice to Spines.__getitem__)
* :ghpull:`26811`: Add overload for slice to Spines.__getitem__
* :ghpull:`26799`: Update kiwisolver and pillow versions to be consistent with requirements
* :ghpull:`26809`: Backport PR #26804 on branch v3.8.x (Fix issue with locale comma when not using math text)
* :ghpull:`26789`: Backport changes to contribute from PR #26737
* :ghpull:`26810`: Backport PR #26807 on branch v3.8.x (Catch ValueError to support pytorch (and others) plotting)
* :ghpull:`26807`: Catch ValueError to support pytorch (and others) plotting
* :ghpull:`26804`: Fix issue with locale comma when not using math text
* :ghpull:`26781`: Backport PR #26780 on branch v3.8.x (fix Axes.errorbar docstring)
* :ghpull:`26780`: fix Axes.errorbar docstring
* :ghpull:`26699`: Improve naming of cibuildwheel jobs
* :ghpull:`26605`: ci: Install GTK4 from brew on macOS

Issues (24):

* :ghissue:`27120`: [Bug]: macosx backend pause() cannot be ctrl-c'd
* :ghissue:`27070`: [Bug]: find_nearest_contour deprecated with no replacement?
* :ghissue:`26913`: Should ``ContourSet.allsegs`` and ``.allkinds`` be deprecated?
* :ghissue:`26869`: [Bug]: Plot window not shown in Mac OS with backend set to default MacOSX
* :ghissue:`16865`: Hexbin mincnt parameter docstring should say "more than or equal to" not "more than"
* :ghissue:`27103`: [Bug]: hexbin cannot always accept np.max like functions as reduce_C_function
* :ghissue:`27062`: [Bug]: ContourLabeler.clabel with manual != False breaks unconnected contours
* :ghissue:`26971`: [Bug]: plt.clabel raises exception at very low DPI: ``ValueError: 'codes' must be a 1D list or array with the same length of 'vertices'. Your vertices have shape (2, 2) but your codes have shape (1,)``
* :ghissue:`27188`: Small error in docstring of matplotlib.colors.from_levels_and_colors
* :ghissue:`27126`: [Bug]: LinearSegmentedColormap.from_list cannot process list with two colors
* :ghissue:`26244`: [Doc]: document how to get list of registered colormaps
* :ghissue:`26863`: [Doc]: ``ContourSet`` ``allsegs`` and ``allkinds`` after #25247
* :ghissue:`26932`: [Bug]: Poetry installs setuptools-scm and setuptools
* :ghissue:`27007`: [Bug]: Colorbar format string kind guess could be made more robust
* :ghissue:`26919`: [Bug]: Missing file pyplot.pyi for mypy typing
* :ghissue:`26949`: [Bug]: colors.LinearSegmentedColormap.from_list does not take two tuples in 3.8.0
* :ghissue:`26936`: [Bug/TYPE]: Scatter ``c`` Typehint does not support list of numbers when using ``cmap``
* :ghissue:`26846`: [MNT]: setuptools-scm v8.0.1 compatibility
* :ghissue:`26821`: [Bug]: ``ValueError: The truth value...`` when an ndarray is passed to the ``color`` kwarg of ``axes3d.scatter``
* :ghissue:`26822`: [Bug]: QuadMesh.get_array change breaks seaborn heatmap annotation
* :ghissue:`26824`: [Bug]: Legend fails for bar plot with numeric label
* :ghissue:`26808`: [Bug]: No overload variant of "__getitem__" of "Spines" matches argument type "slice"  [call-overload]
* :ghissue:`26806`: [Bug]: ValueError when plotting 2D pytorch tensor using matplotlib==3.8.0
* :ghissue:`26803`: [Bug]: use_locale leads to curly brackets around decimal separator
